Learn R Programming

easystats (version 0.4.3)

on_CRAN: Show weeks since last package update on CRAN

Description

Green indicates that enough time since last submission has passed and it's ok to submit an update, yellow means it's ok, but beware it's not too often, and red means that you should probably not yet submit an update.

Usage

on_CRAN()

Arguments