Reports download statistics for easystats packages
Source:R/easystats_downloads.R
easystats_downloads.RdThis function reports download statistics for easystats packages from CRAN
through the cranlogs package.
Arguments
- from
Starting date for the download statistics. Defaults to
"2019-02-26", which is when the first easystats package was released on CRAN.- sort_by
Name of the column that should be used for sorting. Can be
"package","total", or"monthly". UseNULLfor no sorting. Defaults to"total"(total downloads).- length
Numeric, maximum length of the returned string. If not
NULL, will shorten the string to a maximumlength, however, it will not truncate inside words. I.e. if the string length happens to be inside a word, this word is removed from the returned string, so the returned string has a maximum length oflength, but might be shorter.
Examples
# \dontrun{
easystats_downloads()
#> Package | Total | Monthly
#> ----------------------------------
#> insight | 10,935,694 | 122,873
#> datawizard | 7,340,273 | 118,392
#> performance | 5,024,146 | 57,093
#> parameters | 4,840,603 | 57,626
#> bayestestR | 4,804,231 | 54,594
#> effectsize | 3,592,203 | 44,348
#> correlation | 1,352,023 | 17,559
#> see | 1,101,921 | 12,666
#> modelbased | 818,078 | 10,355
#> report | 409,714 | 6,402
#> easystats | 189,045 | 3,938
#> Total | 40,407,931 | 505,846
# }