Reports download statistics for easystats packages
Source:R/easystats_downloads.R
easystats_downloads.RdThis function reports download statistics for easystats packages from CRAN
through the cranlogs package.
Arguments
- from
Starting date for the download statistics. Defaults to
"2019-02-26", which is when the first easystats package was released on CRAN.- sort_by
Name of the column that should be used for sorting. Can be
"package","total", or"monthly". UseNULLfor no sorting. Defaults to"total"(total downloads).- length
Numeric, maximum length of the returned string. If not
NULL, will shorten the string to a maximumlength, however, it will not truncate inside words. I.e. if the string length happens to be inside a word, this word is removed from the returned string, so the returned string has a maximum length oflength, but might be shorter.
Examples
# \dontrun{
easystats_downloads()
#> Package | Total | Monthly
#> ----------------------------------
#> insight | 10,514,585 | 122,263
#> datawizard | 7,015,347 | 118,904
#> performance | 4,775,571 | 56,183
#> parameters | 4,633,145 | 57,199
#> bayestestR | 4,566,007 | 53,718
#> effectsize | 3,437,564 | 44,071
#> correlation | 1,295,588 | 17,508
#> see | 1,047,059 | 12,465
#> modelbased | 768,285 | 10,109
#> report | 390,006 | 6,394
#> easystats | 175,799 | 3,907
#> Total | 38,618,956 | 502,721
# }