Reports download statistics for easystats packages
Source:R/easystats_downloads.R
easystats_downloads.RdThis function reports download statistics for easystats packages from CRAN
through the cranlogs package.
Arguments
- from
Starting date for the download statistics. Defaults to
"2019-02-26", which is when the first easystats package was released on CRAN.- sort_by
Name of the column that should be used for sorting. Can be
"package","total", or"monthly". UseNULLfor no sorting. Defaults to"total"(total downloads).- length
Numeric, maximum length of the returned string. If not
NULL, will shorten the string to a maximumlength, however, it will not truncate inside words. I.e. if the string length happens to be inside a word, this word is removed from the returned string, so the returned string has a maximum length oflength, but might be shorter.
Examples
# \dontrun{
easystats_downloads()
#> Package | Total | Monthly
#> ----------------------------------
#> insight | 10,307,619 | 121,266
#> datawizard | 6,845,350 | 118,023
#> performance | 4,659,354 | 55,468
#> parameters | 4,528,579 | 56,607
#> bayestestR | 4,458,789 | 53,081
#> effectsize | 3,365,031 | 43,702
#> correlation | 1,269,259 | 17,387
#> see | 1,025,068 | 12,350
#> modelbased | 745,162 | 9,935
#> report | 378,178 | 6,303
#> easystats | 168,200 | 3,823
#> Total | 37,750,589 | 497,945
# }