Learn R Programming

easystats (version 0.4.3)

install_latest: Install the easystats suite from R-universe (GitHub) or CRAN

Description

This function can be used to install all the easystats packages, either latest development versions (from R-universe/GitHub) or the current versions from CRAN. If the development versions are installed, packages will be installed from the stable branch (master/main) for each package.

Usage

install_latest(source = c("development", "cran"))

Arguments

source

Character. Either "development" or "cran". If "cran", packages will be installed from the default CRAN mirror returned by getOption("repos")['CRAN'].