This function can be used to install all the easystats packages, either latest development versions (from R-universe/GitHub) or the current versions from CRAN. If the development versions are installed, packages will be installed from the stable branch (master/main) for each package.
install_latest(source = c("development", "cran"))Character. Either "development" or "cran". If "cran", packages will be installed from the default CRAN mirror returned by getOption("repos")['CRAN'].