install_suggested: Download all suggested packages
Description
In easystats, we have a 0-dependency policy, which makes our packages
fairly light and fast to install. However, we rely on many many (many)
packages for testing (at least all the packages for functions that we
support) and some specific features. These "soft dependencies" can be
downloaded at once using this function. This will allow you to fully utilize
100\
Usage
install_suggested(package = "easystats")
show_suggested(package = "easystats")
show_reverse_dependencies(package = "easystats")
Value
Useful only for its side-effect of installing the needed packages.
Arguments
package
If NULL or "easystats" (the default), all suggested
packages for all 'easystats' packages will be installed. If specific
packages are specified, only suggested packages for those packages will be
installed.
Details
To reduce the dependency load, 'easystats' packages by default will not
download all internally needed packages. It will ask the user to download
them only if they are needed. The current function can help install all
packages a given 'easystats' package might need. For example,
install_suggested("see"). show_suggested() is a convenient helper
to show the current list of suggested packages for each 'easystats'
package.