Learn R Programming

easystats (version 0.4.3)

install_suggested: Download all suggested packages

Description

In easystats, we have a 0-dependency policy, which makes our packages fairly light and fast to install. However, we rely on many many (many) packages for testing (at least all the packages for functions that we support) and some specific features. These "soft dependencies" can be downloaded at once using this function. This will allow you to fully utilize 100\

Usage

install_suggested(package = "easystats")

Arguments

package

If NULL, all suggested packages for all 'easystats' packages will be installed. If specific packages are specified, only suggested packages for those packages will be installed.

Value

Useful only for its side-effect of installing the needed packages.

Details

To reduce the dependency load, 'easystats' packages by default will not download all internally needed packages. It will ask the user to download them only if they are needed. The current function can help install all packages a given 'easystats' package might need. For example, install_suggested("see").

Examples

Run this code
# NOT RUN {
install_suggested("easystats")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab